Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
Debug bool
)
Functions ¶
func MatchBranchPattern ¶
func ParseBranchPattern ¶
func Run ¶
Run starts an API server and a `buildkite-agent` process that is listening for jobs against that api.
An initial command is used to upload some pipeline yaml to the server, which is then broken up into steps and run through foreground processing and filtering based on the runner params.
Steps are then added as scheduled Jobs via the API server, where they are processed by the waiting agent process. The API server handles results and state change and finally updates the state of the job.
Types ¶
type Agent ¶
type Artifact ¶
type Artifact struct {
ID string `json:"-"`
Path string `json:"path"`
AbsolutePath string `json:"absolute_path"`
GlobPath string `json:"glob_path"`
FileSize int64 `json:"file_size"`
Sha1Sum string `json:"sha1sum"`
URL string `json:"url,omitempty"`
UploadDestination string `json:"upload_destination,omitempty"`
// contains filtered or unexported fields
}
type Job ¶
type Job struct {
ID string
Build Build
State string
ProjectSlug string
PipelineSlug string
OrganizationSlug string
ArtifactPaths []string
CreatorName string
CreatorEmail string
Command string
Label string
Timeout int
Repository string
Commit string
Branch string
Tag string
Message string
RetryCount int
Plugins []Plugin
Env []string
Artifacts []Artifact
}
Click to show internal directories.
Click to hide internal directories.